Package: bold
Version: 1.3.0
Title: Interface to Bold Systems API
Authors@R: c(person("Salix", "Dubois", role = c("aut", "cre"), 
                    email = "salixdubois+bold@gmail.com"),
             person("Scott", "Chamberlain", role = c("aut"),
                    email = "myrmecocystus@gmail.com",
                    comment = c(ORCID="0000-0003-1444-9135")))
Depends: R (>= 2.10)
Suggests: sangerseqR, testthat, vcr (>= 0.5.4), tibble
Imports: xml2, crul (>= 0.3.8), stringi, jsonlite, data.table, methods
Description: A programmatic interface to the Web Service methods provided by
    Bold Systems (<http://www.boldsystems.org/>) for genetic 'barcode' data.
    Functions include methods for searching by sequences by taxonomic names,
    ids, collectors, and institutions; as well as a function for searching
    for specimens, and downloading trace files.
License: MIT + file LICENSE
URL: https://docs.ropensci.org/bold/ (documentation),
        https://github.com/ropensci/bold (source)
BugReports: https://github.com/ropensci/bold/issues
LazyData: yes
Encoding: UTF-8
RoxygenNote: 7.2.3
X-schema.org-applicationCategory: Data Access
X-schema.org-keywords: biodiversity, barcode, DNA, sequences, fasta
X-schema.org-isPartOf: https://ropensci.org
NeedsCompilation: no
Packaged: 2023-05-01 19:56:58 UTC; salix
Author: Salix Dubois [aut, cre],
  Scott Chamberlain [aut] (<https://orcid.org/0000-0003-1444-9135>)
Maintainer: Salix Dubois <salixdubois+bold@gmail.com>
Repository: CRAN
Date/Publication: 2023-05-02 17:40:02 UTC
