b_dataTypes <- c(
  "basic",
  "stats",
  "geo",
  "images",
  "sequencinglabs",
  "depository",
  "thirdparty",
  "all"
)
b_tax_division <- c("Animalia", "Protista", "Fungi", "Plantae")
b_tax_rank <-
  c(
    "kingdom",
    "phylum",
    "class",
    "order",
    "family",
    "subfamily",
    "tribe",
    "genus",
    "species",
    "subspecies"
  )
b_db <- c('COX1', 'COX1_SPECIES', 'COX1_SPECIES_PUBLIC', 'COX1_L640bp')
